==> apache-servicecomb-java-chassis-distribution-1.3.11-src.zip: apache-servicecomb-java-chassis-distribution-1.3.11-src/integration-tests/it-consumer/src/main/java/org/apache/servicecomb/it/extend/engine/ITClientHttpRequest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.it.extend.engine;

import java.net.URI;

import org.apache.servicecomb.core.CseContext;
import org.apache.servicecomb.core.provider.consumer.ReferenceConfig;
import org.apache.servicecomb.provider.springmvc.reference.CseClientHttpRequest;
import org.springframework.http.HttpMethod;

public class ITClientHttpRequest extends CseClientHttpRequest {
  private String transport;

  public ITClientHttpRequest(URI uri, HttpMethod method, String transport) {
    super(uri, method);
    this.transport = transport;
  }

  @Override
  protected ReferenceConfig findReferenceConfig(String microserviceName) {
    ReferenceConfig referenceConfig = CseContext.getInstance().getConsumerProviderManager()
        .createReferenceConfig(microserviceName);
    if (transport != null) {
      referenceConfig.setTransport(transport);
    }
    return referenceConfig;
  }
}

==> apache-servicecomb-java-chassis-distribution-2.7.1-src.zip: apache-servicecomb-java-chassis-distribution-2.7.1-src/integration-tests/it-consumer/src/main/java/org/apache/servicecomb/it/extend/engine/ITClientHttpRequest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.it.extend.engine;

import java.net.URI;

import org.apache.servicecomb.provider.springmvc.reference.CseClientHttpRequest;
import org.apache.servicecomb.provider.springmvc.reference.RequestMeta;
import org.springframework.http.HttpMethod;

public class ITClientHttpRequest extends CseClientHttpRequest {
  private String transport;

  public ITClientHttpRequest(URI uri, HttpMethod method, String transport) {
    super(uri, method);
    this.transport = transport;
  }

  @Override
  protected RequestMeta createRequestMeta(String httpMethod, URI uri) {
    RequestMeta requestMeta = super.createRequestMeta(httpMethod, uri);
    if (transport != null) {
      requestMeta.getReferenceConfig().setTransport(transport);
    }
    return requestMeta;
  }
}
